# TODO: Fill out this file with information about your package

# HINT: Go back to the object-oriented programming lesson "Putting Code on PyPi" and "Exercise: Upload to PyPi"

# HINT: Here is an example of a setup.py file
# https://packaging.python.org/tutorials/packaging-projects/

from setuptools import setup

setup(name='tomshapes',
      version='1.0.1',
      description='Python Shapes distro',
      author='Tom Mathew',
      author_email='something@nothing.com',
      url='https://nothing.com/',
      packages=['tomshapes'],
     )
